pub struct RedisSource { /* private fields */ }Expand description
A configured Redis source that reads records from Redis data structures.
Implementations
Sourceimpl RedisSource
impl RedisSource
Sourcepub fn new(config: RedisSourceConfig) -> Self
pub fn new(config: RedisSourceConfig) -> Self
Create a new Redis source from the given configuration.